"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const imports_1 = require("./imports");
const typescript_1 = __importDefault(require("typescript"));
function genInlineSourceFile(sourceCode) {
    const fileName = "inline.ts";
    const host = {
        getCompilationSettings: () => ({
            target: typescript_1.default.ScriptTarget.ES2022,
            module: typescript_1.default.ModuleKind.CommonJS,
        }),
        getCurrentDirectory: () => process.cwd(),
        getDefaultLibFileName: (options) => typescript_1.default.getDefaultLibFilePath(options),
        getScriptFileNames: () => [fileName],
        getScriptVersion: () => "0",
        getScriptSnapshot: (name) => name === fileName ? typescript_1.default.ScriptSnapshot.fromString(sourceCode) : undefined,
        readFile: () => undefined,
        fileExists: () => true,
    };
    const service = typescript_1.default.createLanguageService(host);
    const program = service.getProgram();
    (0, vitest_1.expect)(program).toBeDefined();
    const sourceFile = program.getSourceFile(fileName);
    (0, vitest_1.expect)(sourceFile).toBeDefined();
    return sourceFile;
}
(0, vitest_1.test)("case: direct import", () => {
    const importStat = `import "fs";`;
    const sourceFile = genInlineSourceFile(importStat);
    typescript_1.default.forEachChild(sourceFile, (node) => {
        if (!typescript_1.default.isImportDeclaration(node)) {
            return;
        }
        const elements = (0, imports_1.extractImportElements)(sourceFile, node);
        (0, vitest_1.expect)(elements.length).toEqual(1);
        (0, vitest_1.expect)(elements[0]).toEqual({
            type: imports_1.ImportType.Direct,
            name: "",
            package: "fs",
        });
    });
});
(0, vitest_1.test)("case: named import + default import", () => {
    const importStat = `import element, { another } from "library"`;
    const sourceFile = genInlineSourceFile(importStat);
    typescript_1.default.forEachChild(sourceFile, (node) => {
        if (!typescript_1.default.isImportDeclaration(node)) {
            return;
        }
        const elements = (0, imports_1.extractImportElements)(sourceFile, node);
        (0, vitest_1.expect)(elements).toHaveLength(2);
        (0, vitest_1.expect)(elements[0]).toEqual({
            type: imports_1.ImportType.Default,
            name: "element",
            package: "library",
        });
    });
});
(0, vitest_1.test)("case: namespace import", () => {
    const importStat = `import * as element from "library"`;
    const sourceFile = genInlineSourceFile(importStat);
    typescript_1.default.forEachChild(sourceFile, (node) => {
        if (!typescript_1.default.isImportDeclaration(node)) {
            return;
        }
        const elements = (0, imports_1.extractImportElements)(sourceFile, node);
        (0, vitest_1.expect)(elements).toHaveLength(1);
        (0, vitest_1.expect)(elements[0]).toEqual({
            type: imports_1.ImportType.Namespace,
            name: "element",
            package: "library",
        });
    });
});
//# sourceMappingURL=imports.test.js.map